@@ -20,6 +20,8 @@ use IO::Async::Loop;
 use Getopt::Long;
 use Pod::Usage;
 
+use Log::Any::Adapter qw(Stdout), log_level => 'trace';
+
 GetOptions(
     'p|port' => \my $port,
     'h|host' => \my $host,
@@ -46,21 +48,18 @@ my (@channels) = @ARGV or die 'need at least one channel to listen on';
 Future->wait_any(
     $redis->connect
         ->then(sub {
-            Future->needs_all(
-                map {
-                    $redis->subscribe($_)
-                        ->then(sub {
-                            my $sub = shift;
-                            $sub->events
-                                ->sprintf_methods('%s => %s', qw(channel payload))
-                                ->say
-                                ->completed
-                                ->on_done(sub {
-                                    say $_ // '<undef>' for @_;
-                                })
-                        })
-                } @channels
-            )
+            $redis->subscribe(@channels)
+                ->then(sub {
+                    Future->needs_all(
+                        map $_->events
+                            ->sprintf_methods('%s => %s', qw(channel payload))
+                            ->say
+                            ->completed
+                            ->on_done(sub {
+                                say $_ // '<undef>' for @_;
+                            }), @_
+                    )
+                })
         }),
     $loop->timeout_future(after => $timeout),
 )->get;
